==> qmmp_0.4.3.orig.tar.gz: qmmp-0.4.3/src/plugins/Input/flac/translations/flac_plugin_es.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="es">
<context>
    <name>DecoderFLACFactory</name>
    <message>
        <location filename="../decoderflacfactory.cpp" line="51"/>
        <source>FLAC Plugin</source>
        <translation>Módulo FLAC</translation>
    </message>
    <message>
        <location filename="../decoderflacfactory.cpp" line="53"/>
        <source>FLAC Files</source>
        <translation>Archivos FLAC</translation>
    </message>
    <message>
        <location filename="../decoderflacfactory.cpp" line="151"/>
        <source>About FLAC Audio Plugin</source>
        <translation>Acerca del módulo de audio FLAC</translation>
    </message>
    <message>
        <location filename="../decoderflacfactory.cpp" line="152"/>
        <source>Qmmp FLAC Audio Plugin</source>
        <translation>Módulo de audio FLAC para Qmmp</translation>
    </message>
    <message>
        <location filename="../decoderflacfactory.cpp" line="153"/>
        <source>Writen by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>Escrito por: Ilja Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
</context>
<context>
    <name>FLACMetaDataModel</name>
    <message>
        <location filename="../flacmetadatamodel.cpp" line="81"/>
        <source>Length</source>
        <translation>Duración</translation>
    </message>
    <message>
        <location filename="../flacmetadatamodel.cpp" line="82"/>
        <source>Sample rate</source>
        <translation>Frecuencia</translation>
    </message>
    <message>
        <location filename="../flacmetadatamodel.cpp" line="82"/>
        <source>Hz</source>
        <translation>Hz</translation>
    </message>
    <message>
        <location filename="../flacmetadatamodel.cpp" line="83"/>
        <source>Channels</source>
        <translation>Canales</translation>
    </message>
    <message>
        <location filename="../flacmetadatamodel.cpp" line="84"/>
        <source>Bitrate</source>
        <translation>Tasa de bits</translation>
    </message>
    <message>
        <location filename="../flacmetadatamodel.cpp" line="84"/>
        <source>kbps</source>
        <translation>kbps</translation>
    </message>
    <message>
        <location filename="../flacmetadatamodel.cpp" line="86"/>
        <source>File size</source>
        <translation>Tamaño del archivo</translation>
    </message>
    <message>
        <location filename="../flacmetadatamodel.cpp" line="86"/>
        <source>KB</source>
        <translation>KB</translation>
    </message>
</context>
</TS>

==> qmmp_0.5.5.orig.tar.gz: qmmp-0.5.5/src/plugins/Input/flac/translations/flac_plugin_es.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="es">
<context>
    <name>DecoderFLACFactory</name>
    <message>
        <location filename="../decoderflacfactory.cpp" line="51"/>
        <source>FLAC Plugin</source>
        <translation>Módulo FLAC</translation>
    </message>
    <message>
        <location filename="../decoderflacfactory.cpp" line="53"/>
        <source>FLAC Files</source>
        <translation>Archivos FLAC</translation>
    </message>
    <message>
        <location filename="../decoderflacfactory.cpp" line="183"/>
        <source>About FLAC Audio Plugin</source>
        <translation>Acerca del módulo de audio FLAC</translation>
    </message>
    <message>
        <location filename="../decoderflacfactory.cpp" line="184"/>
        <source>Qmmp FLAC Audio Plugin</source>
        <translation>Módulo de audio FLAC para Qmmp</translation>
    </message>
    <message>
        <location filename="../decoderflacfactory.cpp" line="185"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>Escrito por: Ilja Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
</context>
<context>
    <name>FLACMetaDataModel</name>
    <message>
        <location filename="../flacmetadatamodel.cpp" line="82"/>
        <source>Length</source>
        <translation>Duración</translation>
    </message>
    <message>
        <location filename="../flacmetadatamodel.cpp" line="83"/>
        <source>Sample rate</source>
        <translation>Frecuencia</translation>
    </message>
    <message>
        <location filename="../flacmetadatamodel.cpp" line="83"/>
        <source>Hz</source>
        <translation>Hz</translation>
    </message>
    <message>
        <location filename="../flacmetadatamodel.cpp" line="84"/>
        <source>Channels</source>
        <translation>Canales</translation>
    </message>
    <message>
        <location filename="../flacmetadatamodel.cpp" line="85"/>
        <source>Bitrate</source>
        <translation>Tasa de bits</translation>
    </message>
    <message>
        <location filename="../flacmetadatamodel.cpp" line="85"/>
        <source>kbps</source>
        <translation>kbps</translation>
    </message>
    <message>
        <location filename="../flacmetadatamodel.cpp" line="87"/>
        <source>File size</source>
        <translation>Tamaño del archivo</translation>
    </message>
    <message>
        <location filename="../flacmetadatamodel.cpp" line="87"/>
        <source>KB</source>
        <translation>KB</translation>
    </message>
</context>
</TS>
